==> constructorio-ui-quizzes-1.12.0.tgz: package/lib/mjs/components/ShareResultsModal/EmailField.js <==
import React, { useState } from 'react';
import CheckMarkCircleSVG from './CheckMarkCircleSVG';
import AlertCircleSVG from './AlertCircleSVG';
export default function EmailField({ onSubmit }) {
    const [formError, setFormError] = useState(null);
    const [isSubmitted, setIsSubmitted] = useState(false);
    const [email, setEmail] = useState('');
    const validate = () => {
        if (email.length > 0 && /^[^\s@]+@[^\s@]+\.[^\s@]+$/.test(email)) {
            setFormError(null);
            return true;
        }
        setFormError({ type: 'validate', message: 'Please enter a valid email address' });
        return false;
    };
    const handleSubmit = async (e) => {
        e.preventDefault();
        const isValid = validate();
        if (!isValid)
            return;
        try {
            await onSubmit(email);
            setIsSubmitted(true);
        }
        catch (_e) {
            setFormError({
                type: 'callback',
                message: 'Sorry, there was an error sending. Please try again.',
            });
        }
    };
    return (React.createElement("div", { className: 'cio-share-results-feature-group' },
        React.createElement("form", { onSubmit: handleSubmit },
            React.createElement("div", { className: 'cio-share-results-description' }, "Share by email"),
            React.createElement("div", { className: 'cio-share-results-button-group' },
                React.createElement("div", { className: 'cio-share-results-email-input-group' },
                    React.createElement("input", { className: `cio-share-results-email-input ${formError ? 'cio-share-results-email-input--error' : ''}`, onChange: (e) => setEmail(e.target.value) }),
                    formError?.type === 'validate' && (React.createElement("div", { className: 'cio-share-results-email-input-error-message' }, formError.message))),
                React.createElement("button", { className: 'cio-share-results-share-button', type: 'submit' }, "Send"))),
        isSubmitted && (React.createElement("div", { className: 'cio-share-results-notification' },
            React.createElement(CheckMarkCircleSVG, null),
            React.createElement("div", null, "Email sent"))),
        formError?.type === 'callback' && (React.createElement("div", { className: 'cio-share-results-notification' },
            React.createElement(AlertCircleSVG, null),
            React.createElement("div", null, formError.message)))));
}

==> constructorio-ui-quizzes-1.17.13.tgz: package/lib/mjs/components/ShareResultsModal/EmailField.js <==
import React, { useEffect, useState } from 'react';
import CheckMarkCircleSVG from './CheckMarkCircleSVG';
import AlertCircleSVG from './AlertCircleSVG';
import Toaster from './Toaster';
export default function EmailField({ onSubmit }) {
    const [formError, setFormError] = useState(null);
    const [isSubmitted, setIsSubmitted] = useState(false);
    const [email, setEmail] = useState('');
    const [showNotification, setShowNotification] = React.useState(false);
    const validate = () => {
        if (email.length > 0 && /^[^\s@]+@[^\s@]+\.[^\s@]+$/.test(email)) {
            setFormError(null);
            return true;
        }
        setFormError({ type: 'validate', message: 'Please enter a valid email address' });
        return false;
    };
    const handleSubmit = async (e) => {
        e.preventDefault();
        const isValid = validate();
        if (!isValid)
            return;
        try {
            await onSubmit(email);
            setIsSubmitted(true);
        }
        catch (_e) {
            setFormError({
                type: 'callback',
                message: 'Sorry, there was an error sending. Please try again.',
            });
        }
    };
    const onCloseToaster = () => {
        setShowNotification(false);
        setIsSubmitted(false);
        setFormError(null);
    };
    useEffect(() => {
        if (isSubmitted || formError?.type === 'callback') {
            setShowNotification(true);
        }
    }, [isSubmitted, formError?.type]);
    return (React.createElement("div", { className: 'cio-share-results-feature-group' },
        React.createElement("form", { onSubmit: handleSubmit },
            React.createElement("div", { className: 'cio-share-results-description' }, "Share by email"),
            React.createElement("div", { className: 'cio-share-results-button-group' },
                React.createElement("div", { className: 'cio-share-results-email-input-group' },
                    React.createElement("input", { className: `cio-share-results-email-input ${formError ? 'cio-share-results-email-input--error' : ''}`, onChange: (e) => setEmail(e.target.value), placeholder: 'Enter an email address to receive and share the results' }),
                    formError?.type === 'validate' && (React.createElement("div", { className: 'cio-share-results-email-input-error-message' }, formError.message))),
                React.createElement("button", { className: 'cio-share-results-share-button', type: 'submit' }, "Send"))),
        showNotification && (React.createElement(Toaster, { icon: isSubmitted ? CheckMarkCircleSVG : AlertCircleSVG, message: isSubmitted ? 'Email sent' : formError?.message, onCloseToaster: onCloseToaster }))));
}
